<h1 align = "center">:rocket: 各种映射各种平滑 :facepunch:</h1>

---
- [贝叶斯平滑][0]
- [分箱平滑][1]



---
[0]: https://github.com/Jie-Yuan/2_DataMining/blob/master/3_FeatureEngineering/SmoothMapping/BayesianSmoothing.py
